==> xl-react-components-0.16.62.tgz: package/app/xl-react-dip/xl-react-dip-map-string-string/scrollable-container.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import {SortDirection} from 'react-virtualized';
import {localeMessages} from '../../services/locale-service';
import {xlMessageTypeProp} from '../../xl-props/xl-message-type-prop';
import {filterModel, sortTableData} from './xl-react-dip-map-string-string-service';
import MapTable from './map-table';
import {COLUMNS, appendNewKeyValueRow} from './map-table-utils';

import './scrollable-container.less';
import './map-table.less';

export class ScrollableContainer extends Component {
    static propTypes = {
        assignRef: PropTypes.func.isRequired,
        assignTableRef: PropTypes.func.isRequired,
        assignTableWrapperRef: PropTypes.func.isRequired,
        cellState: PropTypes.shape({
            column: PropTypes.oneOf([COLUMNS.key, COLUMNS.value]).isRequired,
            row: PropTypes.number.isRequired,
            value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]).isRequired
        }),
        disabled: PropTypes.bool.isRequired,
        encrypted: PropTypes.bool,
        focus: PropTypes.bool,
        handleCloseButton: PropTypes.func.isRequired,
        handleKeyBlur: PropTypes.func.isRequired,
        handleNewKeyBlur: PropTypes.func.isRequired,
        handleNewKeyChange: PropTypes.func.isRequired,
        handleNewKeyFocus: PropTypes.func.isRequired,
        handleNewValueBlur: PropTypes.func.isRequired,
        handleNewValueFocus: PropTypes.func.isRequired,
        handleNewValueKeyDown: PropTypes.func.isRequired,
        handleRemoveKey: PropTypes.func.isRequired,
        handleSortChange: PropTypes.func.isRequired,
        handleValueChange: PropTypes.func.isRequired,
        hasKeyError: PropTypes.bool,
        inputType: PropTypes.oneOf(['password', 'text']).isRequired,
        message: xlMessageTypeProp,
        model: PropTypes.object.isRequired,
        modelKeys: PropTypes.array.isRequired,
        newKey: PropTypes.string,
        newValue: PropTypes.string,
        pristine: PropTypes.bool.isRequired,
        searchWord: PropTypes.string,
        showNewKeyValueRow: PropTypes.bool,
        sorting: PropTypes.shape({
            sortBy: PropTypes.oneOf([COLUMNS.key, COLUMNS.value]).isRequired,
            sortDirection: PropTypes.oneOf([SortDirection.DESC, SortDirection.ASC]).isRequired
        }),
        updateCellState: PropTypes.func.isRequired,
        valid: PropTypes.bool.isRequired
    };

    static getDerivedStateFromProps(props, state) {
        const {
            encrypted,
            model,
            modelKeys,
            searchWord,
            showNewKeyValueRow,
            sorting = {}
        } = props;
        const predicate = R.whereEq({
            model,
            modelKeys,
            searchWord,
            showNewKeyValueRow,
            sorting
        });
        if (!predicate(state)) {
            const filteredPairs = filterModel(model, modelKeys, searchWord, encrypted);
            const modelForTable = appendNewKeyValueRow(
                props.showNewKeyValueRow,
                sortTableData(filteredPairs, sorting.sortBy, sorting.sortDirection)
            );
            return {
                model,
                modelForTable,
                modelKeys,
                searchWord,
                showNewKeyValueRow,
                sorting
            };
        }

        return {};
    }

    state = {};

    handleWrapperBlur = () => {
        this.props.updateCellState();
    };

    assignTableWrapperRef = (ref) => {
        this.props.assignTableWrapperRef(ref);
    };

    assignTableRef = (ref) => {
        this.table = ref;
        this.props.assignTableRef = ref;
    };

    render() {
        const {
            modelKeys,
            focus,
            disabled,
            newKey,
            newValue,
            handleSortChange,
            sorting: {
                sortBy,
                sortDirection
            } = {}
        } = this.props;

        const {modelForTable} = this.state;

        const containerMessage = () => {
            const message = {
                text: R.isEmpty(modelKeys) ?
                    localeMessages.noKeyValueDefined : localeMessages.noSearchResults
            };
            const messageRow = <div className="container-message">{message.text}</div>;
            return modelForTable.length === 0 ? messageRow : null;
        };

        const showRemoveButton = !disabled && Boolean(newKey || newValue);

        return <div className="table-wrapper" onBlur={this.handleWrapperBlur} ref={this.assignTableWrapperRef}>
            <MapTable
                assignTableRef={this.assignTableRef}
                data={modelForTable}
                focus={focus}
                noRowsRenderer={containerMessage}
                onSortChange={handleSortChange}
                showRemoveButton={showRemoveButton}
                sortBy={sortBy}
                sortDirection={sortDirection}
                {...this.props}
            />
        </div>;
    }
}

==> xl-react-components-0.18.103.tgz: package/app/xl-react-dip/xl-react-dip-map-string-string/scrollable-container.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import {SortDirection} from 'react-virtualized';
import {localeMessages} from '../../services/locale-service';
import {xlMessageTypeProp} from '../../xl-props/xl-message-type-prop';
import {filterModel, sortTableData} from './xl-react-dip-map-string-string-service';
import MapTable from './map-table';
import {COLUMNS, appendNewKeyValueRow} from './map-table-utils';

import './scrollable-container.less';
import './map-table.less';

export class ScrollableContainer extends Component {
    static propTypes = {
        assignRef: PropTypes.func.isRequired,
        assignTableRef: PropTypes.func.isRequired,
        assignTableWrapperRef: PropTypes.func.isRequired,
        cellState: PropTypes.shape({
            column: PropTypes.oneOf([COLUMNS.key, COLUMNS.value]).isRequired,
            row: PropTypes.number.isRequired,
            value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]).isRequired
        }),
        disabled: PropTypes.bool.isRequired,
        encrypted: PropTypes.bool,
        focus: PropTypes.bool,
        focusedValue: PropTypes.string,
        handleCloseButton: PropTypes.func.isRequired,
        handleFocus: PropTypes.func.isRequired,
        handleKeyBlur: PropTypes.func.isRequired,
        handleNewKeyBlur: PropTypes.func.isRequired,
        handleNewKeyChange: PropTypes.func.isRequired,
        handleNewKeyFocus: PropTypes.func.isRequired,
        handleNewValueBlur: PropTypes.func.isRequired,
        handleNewValueKeyDown: PropTypes.func.isRequired,
        handleOnPasswordPaste: PropTypes.func,
        handleRemoveKey: PropTypes.func.isRequired,
        handleRevealPassword: PropTypes.func,
        handleSortChange: PropTypes.func.isRequired,
        handleValueChange: PropTypes.func.isRequired,
        hasKeyError: PropTypes.bool,
        inputType: PropTypes.oneOf(['password', 'text']).isRequired,
        message: xlMessageTypeProp,
        model: PropTypes.object.isRequired,
        modelKeys: PropTypes.array.isRequired,
        newKey: PropTypes.string,
        newValue: PropTypes.string,
        passwordsCanBeRevealed: PropTypes.object,
        pristine: PropTypes.bool.isRequired,
        searchWord: PropTypes.string,
        showNewKeyValueRow: PropTypes.bool,
        sorting: PropTypes.shape({
            sortBy: PropTypes.oneOf([COLUMNS.key, COLUMNS.value]).isRequired,
            sortDirection: PropTypes.oneOf([SortDirection.DESC, SortDirection.ASC]).isRequired
        }),
        updateCellState: PropTypes.func.isRequired,
        valid: PropTypes.bool.isRequired
    };

    static getDerivedStateFromProps(props, state) {
        const {
            encrypted,
            model,
            modelKeys,
            searchWord,
            showNewKeyValueRow,
            sorting = {}
        } = props;
        const predicate = R.whereEq({
            model,
            modelKeys,
            searchWord,
            showNewKeyValueRow,
            sorting
        });
        if (!predicate(state)) {
            const filteredPairs = filterModel(model, modelKeys, searchWord, encrypted);
            const modelForTable = appendNewKeyValueRow(
                props.showNewKeyValueRow,
                sortTableData(filteredPairs, sorting.sortBy, sorting.sortDirection)
            );
            return {
                model,
                modelForTable,
                modelKeys,
                searchWord,
                showNewKeyValueRow,
                sorting
            };
        }

        return {};
    }

    state = {};

    handleWrapperBlur = () => {
        this.props.updateCellState();
    };

    assignTableWrapperRef = (ref) => {
        this.props.assignTableWrapperRef(ref);
    };

    assignTableRef = (ref) => {
        this.table = ref;
        this.props.assignTableRef = ref;
    };

    render() {
        const {
            modelKeys,
            focus,
            disabled,
            newKey,
            newValue,
            handleSortChange,
            sorting: {
                sortBy,
                sortDirection
            } = {}
        } = this.props;

        const {modelForTable} = this.state;

        const containerMessage = () => {
            const message = {
                text: R.isEmpty(modelKeys) ?
                    localeMessages.noKeyValueDefined : localeMessages.noSearchResults
            };
            const messageRow = <div className="container-message">{message.text}</div>;
            return modelForTable.length === 0 ? messageRow : null;
        };

        const showRemoveButton = !disabled && Boolean(newKey || newValue);

        return <div className="table-wrapper" onBlur={this.handleWrapperBlur} ref={this.assignTableWrapperRef}>
            <MapTable
                assignTableRef={this.assignTableRef}
                data={modelForTable}
                focus={focus}
                noRowsRenderer={containerMessage}
                onSortChange={handleSortChange}
                showRemoveButton={showRemoveButton}
                sortBy={sortBy}
                sortDirection={sortDirection}
                {...this.props}
            />
        </div>;
    }
}
